==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicSpinnerUI__244.h <==
// final class javax.swing.plaf.basic.BasicSpinnerUI$4

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class de48f4fd05bac354 javax_swing_plaf_basic_BasicSpinnerUI__244

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicSpinnerUI__244_H_
#define _JC_javax_swing_plaf_basic_BasicSpinnerUI__244_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Timer$object;
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_refs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$refs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$nonrefs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vmethods	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtable	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtype	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method$_init$17b8739b949036dc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method$decrement$4d4ad26d1f706e8c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *);
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method_info$decrement$4d4ad26d1f706e8c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method_info$mouseReleased$47ad6ad312932c8e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vmethods {
	void	(*decrement$4d4ad26d1f706e8c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *);
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vmethods	javax_swing_plaf_basic_BasicSpinnerUI__244;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_refs {
	struct _jc_javax_swing_Timer$object	*timer;
	struct _jc_javax_swing_plaf_basic_BasicSpinnerUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$refs {
    _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_refs	javax_swing_plaf_basic_BasicSpinnerUI__244;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_nonrefs {
	jboolean	volatile mouseDown;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_nonrefs	javax_swing_plaf_basic_BasicSpinnerUI__244;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object {
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtype _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicSpinnerUI__244, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicSpinnerUI__244_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicSpinnerUI__244.h <==
// final class javax.swing.plaf.basic.BasicSpinnerUI$4

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class de48f4fd05bac354 javax_swing_plaf_basic_BasicSpinnerUI__244

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicSpinnerUI__244_H_
#define _JC_javax_swing_plaf_basic_BasicSpinnerUI__244_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Timer$object;
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_refs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$refs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$nonrefs	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vmethods	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtable	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtype	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method$_init$17b8739b949036dc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method$decrement$4d4ad26d1f706e8c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method_info$decrement$4d4ad26d1f706e8c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method_info$mouseReleased$47ad6ad312932c8e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vmethods {
	void	(*decrement$4d4ad26d1f706e8c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *) _JC_JCNI_ATTR;
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vmethods	javax_swing_plaf_basic_BasicSpinnerUI__244;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_refs {
	struct _jc_javax_swing_Timer$object	*timer;
	struct _jc_javax_swing_plaf_basic_BasicSpinnerUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$refs {
    _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_refs	javax_swing_plaf_basic_BasicSpinnerUI__244;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_nonrefs {
	jboolean	volatile mouseDown;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$sub_nonrefs	javax_swing_plaf_basic_BasicSpinnerUI__244;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$object {
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicSpinnerUI__244$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$vtype _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicSpinnerUI__244, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicSpinnerUI__244$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicSpinnerUI__244_H_ */
